from indice_pollution.regions import ForecastMixin, EpisodeMixin
from dateutil.parser import parse
from datetime import timedelta, date, datetime
from .pays_de_la_loire_epcis import dict_commune_ecpi

class Service(object):
    is_active = True
    website = 'http://www.airpl.org/'
    nom_aasqa = 'Air Pays de la Loire'
    use_dateutil_parser = True

    def get_close_insee(self, insee):
        return insee

class Episode(Service, EpisodeMixin):
    url = 'https://data.airpl.org/geoserver/alrt3j_pays_de_la_loire/wfs'
    attributes_key = 'properties'

    def params(self, date_, insee):
        departement = self.departement(insee)
        return {
            "version": "2.0.0",
            "typeName": "alrt3j_pays_de_la_loire:alrt3j_pays_de_la_loire",
            "service": "WFS",
            "outputFormat": "application/json",
            "request": "GetFeature",
            "CQL_FILTER": f"date_ech >= {date_}T00:00:00Z AND code_zone='{departement}'"
        }

class Forecast(Service, ForecastMixin):
    url = 'https://data.airpl.org/api/v1/indice/epci/'

    @classmethod
    def params(cls, date_, insee):
        max_date = date_ + timedelta(days=1)
        return {
            "epci": dict_commune_ecpi[insee],
            "date__range": f"{date_},{max_date}",
            "export": "json"
        }

    def features(self, r):
        return r.json().get('results', [])

    def attributes_getter(self, feature):
        return feature

    def getter(self, feature):
        return super().getter({
            "sous_indices": feature.get('sous_indice'),
            **feature
        })



from . import ServiceMixin, ForecastMixin, EpisodeMixin

class Service(ServiceMixin):
    is_active = True
    website = 'http://www.atmo-grandest.eu/'
    nom_aasqa = 'ATMO Grand Est'
    insee_list = [
        '8105', '57463', '67180', '67482', '88160', '57672', '10387', '68224', '68297',
        '57227', '68066', '52448', '51454', '54395', '51108'
    ]

class Forecast(Service, ForecastMixin):
    url = 'https://services3.arcgis.com/Is0UwT37raQYl9Jj/arcgis/rest/services/ind_grandest_5j/FeatureServer/0/query'
    outfields = ['*']

class Episode(Service, EpisodeMixin):
    url = 'https://services3.arcgis.com/Is0UwT37raQYl9Jj/arcgis/rest/services/alrt3j_grandest/FeatureServer/0/query'


from . import ServiceMixin, ForecastMixin, EpisodeMixin

class Service(ServiceMixin):
    is_active = True
    website =  'https://www.qualitaircorse.org/'
    nom_aasqa = 'Qualitair Corse'
    #insee_list = ['2B033', '2A004', '2B096']

class Forecast(Service, ForecastMixin):
    url = 'https://services9.arcgis.com/VQopoXNvUqHYZHjY/arcgis/rest/services/indice_atmo_communal_corse/FeatureServer/0/query'

    def params(self, date_, insee):
        return {
            "outFields": "*",
            "outSR": "4326",
            "f":"json",
            "where": f"code_zone='{insee}'",
            'orderByFields': 'date_ech DESC',
            'resultRecordCount': 3
        }

class Episode(Service, EpisodeMixin):
    url = 'https://services9.arcgis.com/VQopoXNvUqHYZHjY/arcgis/rest/services/Alrt3j_corse/FeatureServer/0/query'


from indice_pollution.models import db
import requests
import json

class Commune(db.Model):
    __table_args__ = {"schema": "indice_schema"}

    id = db.Column(db.Integer, primary_key=True)
    insee = db.Column(db.String)
    nom = db.Column(db.String)
    code_departement = db.Column(db.String)
    code_region = db.Column(db.String)
    code_zone = db.Column(db.String)
    nom_region = db.Column(db.String)
    _centre = db.Column('centre', db.String)

    @property
    def centre(self):
        return json.loads(self._centre)

    @centre.setter
    def centre(self, value):
        self._centre = json.dumps(value)

    @classmethod
    def get(cls, insee):
        result = db.session.query(cls).filter_by(insee=insee).first()
        if result:
            return result
        r = requests.get(
            f'https://geo.api.gouv.fr/communes/{insee}',
            params={
                "fields": "code,nom,codeDepartement,region,centre",
                "format": "json",
            }
        )
        r.raise_for_status()

        o = cls(
            insee=insee,
            nom=r.json()['nom'],
            code_departement=r.json()['codeDepartement'],
            code_region=r.json()['region']['code'],
            nom_region=r.json()['region']['nom'],
            centre=r.json()['centre']
        )
        db.session.add(o)
        db.session.commit()
        return o